gentle.generators.python — gentle 0.4.0

# gentle.generators.python

Common data for Python generators

Modules

`gentle.generators.python.pkg_info` | Metadata XML generator for Python PEP 643 (PKG-INFO).
`gentle.generators.python.pyproject` | Metadata XML generator for Python PEP 621 (pyproject.toml).
`gentle.generators.python.setuptools` | Metadata XML generator for Python Setuptools (setup.cfg).
`gentle.generators.python.wheel` | Metadata XML generator for Python PEP 517.